@@ -7,7 +7,7 @@ use Thread::Tie ();
 # Make sure we have version info for this module
 # Make sure we do everything by the book from now on
 
-$VERSION = '0.15';
+$VERSION = '0.16';
 use strict;
 
 # Make sure we only load stuff when we actually need it
@@ -414,9 +414,14 @@ It returns undef if no seperate thread is being used.
 The "tid" method returns the thread id of the thread object that is being
 used for the belt.  It returns undef if no seperate thread is being used.
 
+=head1 REQUIRED MODULES
+
+ load (any)
+ Thread::Tie (0.09)
+
 =head1 OPTIMIZATIONS
 
-This module uses L<AutoLoader> to reduce memory and CPU usage. This causes
+This module uses L<load> to reduce memory and CPU usage. This causes
 subroutines only to be compiled in a thread when they are actually needed at
 the expense of more CPU when they need to be compiled.  Simple benchmarks
 however revealed that the overhead of the compiling single routines is not
